@@ -2,7 +2,7 @@
 
 from .models import BaseModel, model, Foreign, Primary, Unique, hook, validate
 from .database import Database
-from ._utils import null, Row, Null
+from ._utils import Row, Null
 from .column import Column, text, integer, blob, real
 from .signature import op
 from .operators import this
@@ -14,14 +14,13 @@ def test_installed():
     return True
 
 
-__version__ = "0.7.5"
+__version__ = "0.7.7"
 __all__ = [
     "Database",
     "Table",
     "this",
     "op",
     "Column",
-    "null",
     "Null",
     "Row",
     "text",
